@@ -1,5 +1,5 @@
-/*  Arg_parser - A POSIX/GNU command line argument parser. C version
-    Copyright (C) 2006, 2007, 2008, 2009 Antonio Diaz Diaz.
+/*  Arg_parser - A POSIX/GNU command line argument parser. (C version)
+    Copyright (C) 2006, 2007, 2008, 2009, 2010 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,16 +31,16 @@
 static const char * invocation_name = 0;
 static const char * const Program_name    = "Arg_parser";
 static const char * const program_name    = "arg_parser";
-static const char * const program_year    = "2009";
+static const char * const program_year    = "2010";
 
 
 void show_help( const char verbose )
   {
   printf( "%s - A POSIX/GNU command line argument parser. (C version)\n", Program_name );
-  printf( "See the source file `main.c' to learn how to use %s in\n", Program_name );
+  printf( "See the source file `cmain.c' to learn how to use %s in\n", Program_name );
   printf( "your own programs.\n" );
   printf( "\nUsage: %s [options]\n", invocation_name );
-  printf( "Options:\n" );
+  printf( "\nOptions:\n" );
   printf( "  -h, --help                   display this help and exit\n" );
   printf( "  -V, --version                output version information and exit\n" );
   printf( "  -a, --append                 example of option with no argument\n" );
@@ -62,7 +62,7 @@ void show_help( const char verbose )
 
 void show_version()
   {
-  printf( "%s %s (C version)\n", Program_name, PROGVERSION );
+  printf( "%s %s\n", Program_name, PROGVERSION );
   printf( "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
   printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n" );
   printf( "This is free software: you are free to change and redistribute it.\n" );
@@ -86,13 +86,13 @@ void show_error( const char * msg, const int errcode, const char help )
 void internal_error( const char * msg )
   {
   char buf[80];
-  snprintf( buf, sizeof( buf ), "internal error: %s.\n", msg );
+  snprintf( buf, sizeof buf, "internal error: %s.\n", msg );
   show_error( buf, 0, 0 );
   exit( 3 );
   }
 
 
-const char * optname( const int code, const ap_Option options[] )
+const char * optname( const int code, const struct ap_Option options[] )
   {
   static char buf[2] = "?";
   int i;
@@ -109,7 +109,7 @@ const char * optname( const int code, const ap_Option options[] )
 int main( const int argc, const char * argv[] )
   {
   char verbose = 0;
-  const ap_Option options[] =
+  const struct ap_Option options[] =
     {
     { 'H', "hidden",   ap_no    },
     { 'V', "version",  ap_no    },
@@ -123,7 +123,8 @@ int main( const int argc, const char * argv[] )
     { 'v', "verbose",  ap_no    },
     { 256, "orphan",   ap_no    },
     {   0, 0,          ap_no    } };
-  Arg_parser parser;
+
+  struct Arg_parser parser;
   int argind;
   invocation_name = argv[0];
 
