@@ -1,5 +1,5 @@
-/*  Arg_parser - A POSIX/GNU command line argument parser.
-    Copyright (C) 2006, 2007, 2008, 2009 Antonio Diaz Diaz.
+/*  Arg_parser - A POSIX/GNU command line argument parser. (C++ version)
+    Copyright (C) 2006, 2007, 2008, 2009, 2010 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,12 +35,12 @@ namespace {
 const char * invocation_name = 0;
 const char * const Program_name    = "Arg_parser";
 const char * const program_name    = "arg_parser";
-const char * const program_year    = "2009";
+const char * const program_year    = "2010";
 
 
 void show_help( const bool verbose )
   {
-  std::printf( "%s - A POSIX/GNU command line argument parser.\n", Program_name );
+  std::printf( "%s - A POSIX/GNU command line argument parser. (C++ version)\n", Program_name );
   std::printf( "See the source file `main.cc' to learn how to use %s in\n", Program_name );
   std::printf( "your own programs.\n" );
   std::printf( "\nUsage: %s [options]\n", invocation_name );
@@ -90,7 +90,7 @@ void show_error( const char * msg, const int errcode = 0, const bool help = fals
 void internal_error( const char * msg )
   {
   char buf[80];
-  std::snprintf( buf, sizeof( buf ), "internal error: %s.\n", msg );
+  std::snprintf( buf, sizeof buf, "internal error: %s.\n", msg );
   show_error( buf );
   std::exit( 3 );
   }
